LoadBundleTaskSnapshot class

A LoadBundleTaskSnapshot is returned as the result or on-going process of a LoadBundleTask.

Properties

bytesLoaded → int
How many bytes have been loaded.
no setter
documentsLoaded → int
How many documents have been loaded.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskState → LoadBundleTaskState
The current load bundle task snapshot state.
no setter
totalBytes → int
The total bytes of the load bundle task.
no setter
totalDocuments → int
How many documents are in the bundle being loaded.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited