VectorValue class

Represents a vector value by an array of doubles.

Annotations

Constructors

VectorValue(List<double> _value)
Create VectorValue instance.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<double>
Converts a VectorValue to a List of double.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override